
"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.http.request.http_request import HttpRequest as CoreHttpRequest


class HttpRequest(CoreHttpRequest):
    """
    Represent an HTTP request to be sent to the server.

    Encapsulates request details such as the HTTP method, target URL, headers,
     query parameters, body parameters, and any files included with the request.

    Attributes:
        http_method: The HTTP method to use for the request.
        query_url (str): The URL to which the request will be sent.
        headers (dict[str, str] | None): Headers to include with the request.
        query_parameters (dict[str, str] | None): Query parameters appended
            to the request URL.
        parameters (dict[str, str] | None): Form or body parameters sent
            with the request.
        files (dict | None): Files to be sent with the request.

    """

    def __init__(self,
                 http_method,
                 query_url,
                 headers=None,
                 query_parameters=None,
                 parameters=None,
                 files=None):
        """
        Initialize an HttpRequest instance.

        Args:
            http_method: The HTTP method to use for the request.
            query_url: The URL to which the request will be sent.
            headers: Headers to include with the request.
            query_parameters: Query parameters appended to the request URL.
            parameters: Form or body parameters sent with the request.
            files: Files to be sent with the request.

        """
        super().__init__(http_method,
                         query_url,
                         headers,
                         query_parameters,
                         parameters,
                         files)
