"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class PaymentMethodEnum(object):
    """Implementation of the 'PaymentMethod' enum.

    The payment method.

    Attributes:
        OTHER: The enum member of type str.
        CREDITCARD: The enum member of type str.
        DEBITACCOUNT: The enum member of type str.
        ACH: The enum member of type str.

    """

    OTHER = "Other"

    CREDITCARD = "CreditCard"

    DEBITACCOUNT = "DebitAccount"

    ACH = "ACH"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default
