"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class RemoveFromWaitlistRequest(object):
    """Implementation of the 'RemoveFromWaitlistRequest' model.

    Attributes:
        waitlist_entry_ids (List[int]): A list of `WaitlistEntryIds` to remove from
            the waiting list.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "waitlist_entry_ids": "WaitlistEntryIds",
    }

    def __init__(
        self,
        waitlist_entry_ids=None):
        """Initialize a RemoveFromWaitlistRequest instance."""
        # Initialize members of the class
        self.waitlist_entry_ids = waitlist_entry_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        waitlist_entry_ids =\
            dictionary.get("WaitlistEntryIds")\
            if dictionary.get("WaitlistEntryIds")\
                else None

        # Return an object of this model
        return cls(waitlist_entry_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _waitlist_entry_ids=self.waitlist_entry_ids
        return (
            f"{self.__class__.__name__}("
            f"waitlist_entry_ids={_waitlist_entry_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _waitlist_entry_ids=self.waitlist_entry_ids
        return (
            f"{self.__class__.__name__}("
            f"waitlist_entry_ids={_waitlist_entry_ids!s}, "
            f")"
        )
