"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class ScheduleType3Enum(object):
    """Implementation of the 'ScheduleType3' enum.

    A schedule type used to filter the returned results. Possible values are:
    * All
    * Class
    * Enrollment
    * Appointment
    * Resource
    * Media
    * Arrival

    Attributes:
        ALL: The enum member of type str.
        CLASS: The enum member of type str.
        ENROLLMENT: The enum member of type str.
        APPOINTMENT: The enum member of type str.
        RESOURCE: The enum member of type str.
        MEDIA: The enum member of type str.
        ARRIVAL: The enum member of type str.

    """

    ALL = "All"

    CLASS = "Class"

    ENROLLMENT = "Enrollment"

    APPOINTMENT = "Appointment"

    RESOURCE = "Resource"

    MEDIA = "Media"

    ARRIVAL = "Arrival"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default
