"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class SendPasswordResetEmailRequest(object):
    """Implementation of the 'SendPasswordResetEmailRequest' model.

    Request to send a password reset email to a user

    Attributes:
        user_email (str): The user’s email address. The software uses this parameter
            as the username.
        user_first_name (str): The user’s first name. The software uses this
            parameter to verify the user.
        user_last_name (str): The user’s last name. The software uses this parameter
            to verify the user.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "user_email": "UserEmail",
        "user_first_name": "UserFirstName",
        "user_last_name": "UserLastName",
    }

    def __init__(
        self,
        user_email=None,
        user_first_name=None,
        user_last_name=None):
        """Initialize a SendPasswordResetEmailRequest instance."""
        # Initialize members of the class
        self.user_email = user_email
        self.user_first_name = user_first_name
        self.user_last_name = user_last_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        user_email =\
            dictionary.get("UserEmail")\
            if dictionary.get("UserEmail")\
                else None
        user_first_name =\
            dictionary.get("UserFirstName")\
            if dictionary.get("UserFirstName")\
                else None
        user_last_name =\
            dictionary.get("UserLastName")\
            if dictionary.get("UserLastName")\
                else None

        # Return an object of this model
        return cls(user_email,
                   user_first_name,
                   user_last_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _user_email=self.user_email
        _user_first_name=self.user_first_name
        _user_last_name=self.user_last_name
        return (
            f"{self.__class__.__name__}("
            f"user_email={_user_email!r}, "
            f"user_first_name={_user_first_name!r}, "
            f"user_last_name={_user_last_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _user_email=self.user_email
        _user_first_name=self.user_first_name
        _user_last_name=self.user_last_name
        return (
            f"{self.__class__.__name__}("
            f"user_email={_user_email!s}, "
            f"user_first_name={_user_first_name!s}, "
            f"user_last_name={_user_last_name!s}, "
            f")"
        )
