"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class ClassClientDetail(object):
    """Implementation of the 'ClassClientDetail' model.

    Class Client Detail Object

    Attributes:
        client_ids (List[str]): The RSSID of the clients to remove from the specified
            classes.
        class_id (int): The ID of the classes that you want to remove the clients
            from.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_ids": "ClientIds",
        "class_id": "ClassId",
    }

    def __init__(
        self,
        client_ids=None,
        class_id=None):
        """Initialize a ClassClientDetail instance."""
        # Initialize members of the class
        self.client_ids = client_ids
        self.class_id = class_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_ids =\
            dictionary.get("ClientIds")\
            if dictionary.get("ClientIds")\
                else None
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else None

        # Return an object of this model
        return cls(client_ids,
                   class_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_ids=self.client_ids
        _class_id=self.class_id
        return (
            f"{self.__class__.__name__}("
            f"client_ids={_client_ids!r}, "
            f"class_id={_class_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_ids=self.client_ids
        _class_id=self.class_id
        return (
            f"{self.__class__.__name__}("
            f"client_ids={_client_ids!s}, "
            f"class_id={_class_id!s}, "
            f")"
        )
